#O objetivo desta função é construir uma matriz a partir de data frames com números diferentes de linha. 
#A primeira coluna dos data frames deverá ser a variável de interesse, e o restante das colunas, os valores de observação de cada caso. 
#A função irá organizar os dataframes levando em conta a variável de interesse.

join.frames<- function(path, na.zero=F, binary=F, transpose=T, file=F)
{
	filenames<- list.files(path) #Objeto com o nome dos arquivos da pasta indicada
	filelist<- lapply(filenames, read.delim) #Objeto tipo lista com todos os data.frames que estão na pasta indicada
	frames<-Reduce(function(x,y) merge(x,y, all=TRUE), filelist) #Junta todos os arquivos de data.frame num arquivo só. Onde não houver dado de uma determinada linha em um dos data.frames, ele vai transformar colocar um NA.
	#Verificar se existe algum nome repetido na variável de interesse
	rownames(frames)<- frames[,1] #Coloca a variável de interesse que está na primeira linha como o nome das linhas.
	frames<- frames[,-1] #Retira a primeira coluna, para deixar o data.frame apenas numérico
	#Se o argumento na.zero=F, ele vai deixar NA. Se o na.zero=T, ele vai transformar os NAs em zero. 
	if(na.zero==T)
	{
		frames[is.na(frames)]<- 0 #Transforma NA em 0
	}
	#Se o argumento binary=F, ele vai deixar os valores que estão nos data.frames. Se binary=T, ele vai tranformar os NAs zero, deixar onde tem zero, e tranformar todas as posições que tem valor em 1.
	if(binary==T)
	{
		frames[is.na(frames)]<- 0 #Transforma NA em 0
		frames[frames>0] <- 1 #Transforma todos os valores acima de 0 em 1
	}
	#Se o argumento transpose=T, ele vai transpor o data.frame. Caso transpose=F, ele vai deixar o data.frame do jeito que está.
	if(transpose==T)
	{
		frames<-t(frames) #Transpõe o data.frame
	}
	#Se o argumento file=NULL, ele vai liberar o data.frame na área de trabalho. Se file="path" ou "file.txt", gravará um arquivo .txt no arquivo indicado ou no diretório de trabalho ativo.
	if(file==F)
	{
		return(frames) #Retorna na área de trabalho o data.frame gerado
	}else
	{
		write.table(frames, file, sep="\t") #Salva o data.frame em um arquivo .txt no diretório ativo
	}
}